<?php

namespace Drupal\flexible_access_group\Access;

use Drupal\group\Access\GroupPermissionChecker;
use Drupal\group\Access\GroupPermissionCalculatorInterface;
use Drupal\group\GroupMembershipLoaderInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\group\Entity\GroupInterface;
use Drupal\Core\Session\AccountProxyInterface;

/**
 * Flexible permission checker to override group permissions.
 */
class FlexibleGroupPermissionChecker extends GroupPermissionChecker {

  protected $innerService;

  public function __construct(
    GroupPermissionCalculatorInterface $permission_calculator,
    GroupMembershipLoaderInterface $group_membership_loader,
    AccountProxyInterface $current_user
  ) {
    parent::__construct($permission_calculator, $group_membership_loader, $current_user);
  }

  /**
   * Sets the inner (original) service.
   */
  public function setInnerService(GroupPermissionChecker $innerService) {
    $this->innerService = $innerService;
  }

  /**
   * Overrides the permission check for groups.
   */
  public function hasPermissionInGroup($permission, AccountInterface $account, GroupInterface $group) {
    // We want to bypass group access permission checker, if we can find a flexible access field,
    // and it is not set to member.
    $flexible_access_field = \Drupal::service('flexible_access.helper')->getFlexibleAccessField($group);
    if (isset($flexible_access_field) && $group->{$flexible_access_field}->target_id !== 'member') {
      return TRUE;
    }
    
    // Otherwise, use the default permission checker.
    return $this->innerService->hasPermissionInGroup($permission, $account, $group);
  }
}
