<?php

declare(strict_types=1);

namespace Drupal\flexible_access\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\flexible_access\FlexibleAccessItemInterface;

/**
 * Defines the flexible access item entity type.
 *
 * @ConfigEntityType(
 *   id = "flexible_access_item",
 *   label = @Translation("Flexible access item"),
 *   label_collection = @Translation("Flexible access items"),
 *   label_singular = @Translation("flexible access item"),
 *   label_plural = @Translation("flexible access items"),
 *   label_count = @PluralTranslation(
 *     singular = "@count flexible access item",
 *     plural = "@count flexible access items",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\flexible_access\FlexibleAccessItemListBuilder",
 *     "form" = {
 *       "add" = "Drupal\flexible_access\Form\FlexibleAccessItemAddForm",
 *       "edit" = "Drupal\flexible_access\Form\FlexibleAccessItemForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm",
 *     },
 *   },
 *   config_prefix = "flexible_access_item",
 *   admin_permission = "administer flexible_access_item",
 *   links = {
 *     "collection" = "/admin/config/flexible-access/flexible-access-item",
 *     "add-form" = "/admin/config/flexible-access/flexible-access-item/add",
 *     "edit-form" = "/admin/config/flexible-access/flexible-access-item/{flexible_access_item}",
 *     "delete-form" = "/admin/config/flexible-access/flexible-access-item/{flexible_access_item}/delete",
 *   },
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "description",
 *     "field",  
 *     "operations",
 *     "dependency",
 *     "weight",
 *   },
 * )
 */
final class FlexibleAccessItem extends ConfigEntityBase implements FlexibleAccessItemInterface {

  /**
   * The id for the flexible access item entity.
   */
  protected string $id;

  /**
   * The flexible access item label.
   */
  protected string $label;

  /**
   * The flexible access item description.
   */
  protected string $description;


  /**
   * The flexible access item field.
   */
  protected string $field;

  /**
   * The flexible access item operation.
   */
  protected array $operations;

  /**
   * Dependency of flexible access item.
   */
  protected mixed $dependency;

  /**
   * Weight of flexible access item.
   */
  protected int $weight = 0;

  /**
   * {@inheritdoc}
   */
  public function getDescription(): string {
    return $this->description; 
  }

}
