<?php

declare(strict_types=1);

namespace Drupal\flexible_access;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Entity\EntityInterface;

/**
 * @todo Add class description.
 */
final class Helper {

  use StringTranslationTrait;

  /**
   * Constructs a Helper object.
   */
  public function __construct(
    private readonly EntityTypeBundleInfoInterface $entityTypeBundleInfo,
    private readonly EntityTypeManagerInterface $entityTypeManager,
    private readonly EntityFieldManagerInterface $entityFieldManager,
    private readonly AccountProxyInterface $currentUser,
    private readonly ConfigFactoryInterface $configFactory,
  ) {}

  /**
   * @todo Add method description.
   */
  public function getSupportedUserReferenceFields(): array {
    $fields = ['_none' => $this->t('- None -')];
    $field_storage_config = $this->entityTypeManager->getStorage('field_storage_config')->loadByProperties([
      'type' => 'entity_reference',
      'settings' => [
        'target_type' => 'user',
      ],
    ]); 
    
    foreach ($field_storage_config as $field) {
      $fields[$field->getName()] = $field->getName() . ' (' . $field->getTargetEntityTypeId() . ')';
    }
    
    return $fields;    
  }

  public function getSupportedOperations(): array {
    return [
      'view' => $this->t('View'),
      'update' => $this->t('Update'),
      'delete' => $this->t('Delete'),
    ];
  }

  public function getSupportedRoles(): array {
    $options = ['_none' => $this->t('- None -')];
    $roles = $this->entityTypeManager->getStorage('user_role')->loadMultiple();
    foreach ($roles as $role) {
      $options[$role->id()] = $role->label();
    }
    return $options;
  }

  public function foundFlexibleAccessField(EntityInterface $entity) {
    $fields = $this->entityFieldManager->getFieldDefinitions($entity->getEntityTypeId(), $entity->bundle());
    foreach ($fields as $field) {
      if ($field->getType() === 'flexible_access_field') {
        return TRUE;
      }
    }
    return FALSE;
  }

  public function getFlexibleAccessField(EntityInterface $entity) {
    $fields = $this->entityFieldManager->getFieldDefinitions($entity->getEntityTypeId(), $entity->bundle());
    foreach ($fields as $field) {
      if ($field->getType() === 'flexible_access_field') {
        return $field->getName();
      }
    }
    return NULL;
  }

  public function getFlexibleAccessItem(string $machine_name): bool {
    if ($this->entityTypeManager->getStorage('flexible_access_item')->load($machine_name)) {
      return TRUE;
    }
    return FALSE;
  }

  public function getAllEnabledFlexibleAccessItems(): array {
    $flexible_access_items = $this->entityTypeManager->getStorage('flexible_access_item')->loadByProperties(['status' => TRUE]);
    $items = [];
    foreach ($flexible_access_items as $machine_name => $flexible_access_item) {
      $items[$machine_name] = $flexible_access_item->label();
    }
    return $items;
  }

}
