<?php

namespace Drupal\flexible_access\Plugin\Field\FieldType;

use Drupal\Core\Field\Plugin\Field\FieldType\EntityReferenceItem;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Core\Messenger\MessengerTrait;

/**
 * Plugin implementation of the 'fexlible_access_field' field type.
 *
 * @FieldType(
 *   id = "flexible_access_field",
 *   label = @Translation("Flexible access field"),
 *   description = @Translation("Flexible Access Field selector."),
 *   category = @Translation("Text"),
 *   default_widget = "flexible_access_default",
 *   default_formatter = "list_default",
 * )
 */
class FlexibleAccessField extends EntityReferenceItem {

  use MessengerTrait;

  /**
   * {@inheritdoc}
   */
  public static function defaultStorageSettings() {
    return array(
      'target_type' => 'flexible_access_item',
      'title' => new TranslatableMarkup('Flexible Access'),
    ) + parent::defaultStorageSettings();
  }  

  /**
   * {@inheritdoc}
   */
  public static function defaultFieldSettings(): array {
    return [
      'target_type' => 'flexible_access_item',
      'handler' => 'default:entity_reference',
      'handler_settings' => [
        'target_bundles' => [],
        'sort' => [
          'field' => '_none',
          'direction' => 'asc',
        ],
        'auto_create' => FALSE,
      ],
    ] + parent::defaultFieldSettings();
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition): array {
    $properties = parent::propertyDefinitions($field_definition);

    $properties['target_id'] = DataDefinition::create('string')
      ->setLabel(t('Flexible Access Item ID'))
      ->setDescription(t('The ID of the flexible access item.'));

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::fieldSettingsForm($form, $form_state);

    $flexible_access_item_options = [];

    $flexible_access_items = \Drupal::entityTypeManager()->getStorage('flexible_access_item')->loadMultiple();
    foreach ($flexible_access_items as $machine_name => $type) {
      $flexible_access_item_options[$machine_name] = $type->label();
    }

    $destination = \Drupal::destination()->getAsArray();
    $url = Url::fromRoute('flexible_access.flexible_access_item_add', [], ['query' => $destination]);
    $link = Link::fromTextAndUrl(t('Add flexible access items'), $url)->toString();
    
    if (empty($flexible_access_item_options)) {
      $this->messenger()->addWarning($this->t('You have to create at least one flexible access item! @link', ['@link' => $link]));      
    }

    return $form;
  }  

  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    return $values;
  }  



}
