<?php

namespace Drupal\flexible_access\Plugin\FlexibleAccessItem;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Access\AccessResultInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\flexible_access\Plugin\FlexibleAccessItemBase;

/**
 * Provides a 'DefaultMemeber' flexible access item.
 *
 * @FlexibleAccessItem(
 *   id = "member",
 *   label = @Translation("Member"),
 * )
 */
class DefaultMember extends FlexibleAccessItemBase {

  /**
   * {@inheritdoc}
   */
  public function getAccessResult(AccountInterface $account, EntityInterface $entity): AccessResultInterface {
    
    $not_a_member = !$entity->getMember($account) || $account->isAnonymous();

    return AccessResult::forbiddenIf($not_a_member)
      ->cachePerPermissions()
      ->cachePerUser()
      ->addCacheableDependency($entity)
      ->addCacheableDependency($account);
      
  }

  /**
   * {@inheritdoc}
   */
  public function getIcon(): string {
    return '<span class="flexible-access-item-icon"><svg xmlns="http://www.w3.org/2000/svg"><path d="M19 7.001c0 3.865-3.134 7-7 7s-7-3.135-7-7c0-3.867 3.134-7.001 7-7.001s7 3.134 7 7.001zm-1.598 7.18c-1.506 1.137-3.374 1.82-5.402 1.82-2.03 0-3.899-.685-5.407-1.822-4.072 1.793-6.593 7.376-6.593 9.821h24c0-2.423-2.6-8.006-6.598-9.819z"/></svg></span>';
  }    

}