<?php

namespace Drupal\flexible_access\Plugin;

use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Component\Utility\Html;

/**
 * Provides the Flexible access item plugin manager.
 */
class FlexibleAccessItemManager extends DefaultPluginManager {

  /**
   * Constructor for FlexibleAccessItemManager objects.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler to invoke the alter hook with.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct('Plugin/FlexibleAccessItem', $namespaces, $module_handler, 'Drupal\flexible_access\Plugin\FlexibleAccessItemInterface', 'Drupal\flexible_access\Annotation\FlexibleAccessItem');

    $this->alterInfo('flexible_access_item_info');
    $this->setCacheBackend($cache_backend, 'flexible_access_item_plugins');
  }

  /**
   * Retrieves an options list of available flexible access items.
   *
   * @return string[]
   *   An associative array mapping the IDs of all available flexible access item plugins to
   *   their labels.
   */
  public function getOptionsList(array $entities = []) {
    $options = [];
    foreach ($this->getDefinitions() as $plugin_id => $plugin_definition) {
      $options[$plugin_id] = Html::escape($plugin_definition['label']);
    }
    return $options;
  }



}
